@@ -1748,7 +1748,8 @@ static int mirror_http(crawl_context_t* context, webbase_url_t* webbase_url, uri
 	  error = errno;
 	  if(verbose > 1) fprintf(stderr, "\terror while reading body (%d)\n", error);
 	}
-      } else {
+      } else if(!(webbase_url->w_info & WEBBASE_URL_INFO_CONTENT) ||
+		webbase_url->w_content_length <= 0) {
 	char* path = uri_furi_string(webbase_url->w_url, strlen(webbase_url->w_url), URI_FURI_REAL_PATH);
 	if(path) {
 	  if(file_exists(path))
