@@ -28,6 +28,10 @@
 #include <robots.h>
 #include <cookies.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define CRAWL_PARAMS_CANDIDATE_LIMIT	200
 
 typedef struct crawl_params {
@@ -64,4 +68,8 @@ void hp_print_externals(crawl_params_t* params, char* where);
 void hp_remove_unloaded(crawl_params_t* params, char* url);
 webbase_url_t* crawl_touch(crawl_params_t* params, char* url);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _crawl_h */
