@@ -19,6 +19,10 @@
 #ifndef _dirsel_h
 #define _dirsel_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define DIRSEL_LOAD	0x01
 #define DIRSEL_RELOAD	0x02
 
@@ -32,4 +36,8 @@ int dirsel_allowed(char* netpath, char* url);
 char* dirsel_key(char* url);
 void dirsel_verbose(int level);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _dirsel_h */
