@@ -1,6 +1,10 @@
 #ifndef _ftp_h
 #define _ftp_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 char *ftplib_lastresp;
 int ftplib_debug;
 void ftpInit(void);
@@ -18,4 +22,8 @@ int ftpRename(char *src, char *dst);
 int ftpDelete(char *fnm);
 void ftpQuit(void);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _ftp_h */
