@@ -21,7 +21,15 @@
 
 #include <webbase_url.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int html_href(char* path, webbase_url_t* webbase_url, int size_limit);
 int html_content_begin(char* buffer, int buffer_length, webbase_url_t* webbase_url);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _html_h */
