@@ -37,7 +37,7 @@
 
 #include <http.h>
 #include <webbase_url.h>
-#include <bodyparse.h>
+#include <html.h>
 #include <webtools.h>
 
 static int verbose = 0;
@@ -102,10 +102,10 @@ int http_header(char* arg, int sd, char* buffer, int buffer_size, int flag)
 	char* tmp;
 	tmp = value++;
 	*tmp = ' ';
-	while(tmp > lines[i] && isspace(*tmp)) *tmp-- = '\0';
-	while(isspace(*value)) value++;
+	while(tmp > lines[i] && isspace((int)*tmp)) *tmp-- = '\0';
+	while(isspace((int)*value)) value++;
 	for(tmp = key; *tmp; tmp++) {
-	  if(isalpha(*tmp)) *tmp = tolower(*tmp);
+	  if(isalpha((int)*tmp)) *tmp = tolower(*tmp);
 	}
 	if(!strcmp(key, "content-type")) {
 	  webbase_url_content_type_set(webbase_url, value);
@@ -180,30 +180,7 @@ int http_body(char* arg, int sd, char* body, int body_size, int flag)
     /*
      * Extract meta information & all. Don't try to find them above 10k.
      */
-    {
-      char* extract; int extract_length;
-      char* keywords; int keywords_length;
-      char* description; int description_length;
-      char* title; int title_length;
-
-      if(bodyparse_string(parse_buffer, parse_buffer_length, 100000000, 0, BODY_PARSE_TRANSPARENT,
-			  &extract, &extract_length,
-			  &keywords, &keywords_length,
-			  &description, &description_length,
-			  &title, &title_length) > 0) {
-#define S(field_length,field,w_field,constant_field_length,flag) \
-	if(field_length) { \
-	  strncpy(webbase_url->w_field, field, constant_field_length); \
-	  webbase_url->w_field[constant_field_length] = '\0'; \
-	  webbase_url->w_info |= flag; \
-        }
-	S(keywords_length,keywords,w_keywords,WEBBASE_KEYWORDS_LENGTH,WEBBASE_URL_INFO_KEYWORDS | WEBBASE_URL_INFO_COMPLETE);
-	S(description_length,description,w_description,WEBBASE_DESCRIPTION_LENGTH,WEBBASE_URL_INFO_DESCRIPTION | WEBBASE_URL_INFO_COMPLETE);
-	S(title_length,title,w_title,WEBBASE_TITLE_LENGTH,WEBBASE_URL_INFO_TITLE);
-	if(verbose > 1) fprintf(stderr, "http_body: extract %.*s\n", extract_length, extract);
-	S(extract_length,extract,w_extract,WEBBASE_EXTRACT_LENGTH,WEBBASE_URL_INFO_EXTRACT);
-      }
-    }
+    html_content_begin(parse_buffer, parse_buffer_length, webbase_url);
   }
 
   webbase_url->w_info |= WEBBASE_URL_INFO_READING;
