@@ -21,8 +21,16 @@
 
 #include <webbase.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 char* mime_ext2mime(webbase_t* base, char* path, char* default_type);
 int mime_accept_ext(webbase_t* base, char* spec, char* path);
 int mime_accept_type(webbase_t* base, char* spec, char* content_type);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif _mime_h
