@@ -22,6 +22,10 @@
 #include <webbase_url.h>
 #include <webbase.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define ROBOTS_NOT_DELAYED	0
 #define ROBOTS_DELAYED		1
 
@@ -69,4 +73,8 @@ void robots_info(robots_t* robots, int robot_delay, uri_t* url_object, time_t* d
 void robots_free(robots_t* params);
 int robots_p(char* path);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _robots_h */
