@@ -19,6 +19,14 @@
 #ifndef _robots_parser_h
 #define _robots_parser_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int robots_parse(char* path, char** allowp, char** disallowp);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _robots_parser_h */
