@@ -22,6 +22,10 @@
 #include <uri.h>
 #include <getopttools.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define WEBTOOLS_READER_HTTP_HEADER		0x0001
 #define WEBTOOLS_READER_RAW			0x0002
 #define WEBTOOLS_READER_HTTP_BODY		WEBTOOLS_READER_RAW
@@ -70,4 +74,8 @@ int webtools_write(webtools_params_t* params, int sd, char* buffer, int size);
 void webtools_close(webtools_params_t* params, int sd);
 int webtools_reader(webtools_params_t* params, int sd);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _webtools_h */
