@@ -32,7 +32,6 @@
 #include <WordType.h>
 #include <Configuration.h>
 
-extern "C" {
 #include <sqlutil.h>
 #include <hooks.h>
 #include <html_content.h>
@@ -42,13 +41,16 @@ extern "C" {
 #include <salloc.h>
 #include <hash.h>
 #include <md5str.h>
+#include <isomap.h>
 #include <mkdirp.h>
-}
 
 static int verbose = 0;
 
 static ConfigDefaults defaults[] = {
   { "wordlist_extend", "true", 0 },
+  { "wordlist_cache_size", "134217728", 0 },
+  { "wordlist_page_size", "32768", 0 },
+  { "wordlist_compress", "1", 0 },
   { "minimum_word_length", "1", 0 },
   { "maximum_word_length", "25", 0 },
   { 0 }
