@@ -19,6 +19,14 @@
 #ifndef _file_isdir_h
 #define _file_isdir_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int file_isdir(char* filename);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* file_isdir_h */
