@@ -21,7 +21,15 @@
 
 #include <getopt.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void getopt_dump(struct option options[]);
 void getopt_merge(struct option to[], struct option from[]);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* getopttools_h */
