@@ -19,6 +19,14 @@
 #ifndef _strsubs_h
 #define _strsubs_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 char* strsubs(char* string, int string_size, int* size, char** from_array, char** to_array);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* strsubs_h */
