@@ -19,6 +19,14 @@
 #ifndef _urldirname_h
 #define _urldirname_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 char* urldirname(char* filename);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* urldirname_h */
